# ASC Media Hash List (ASC MHL) - Specification

The specification documents can be found in the [`mhl-specification`](https://github.com/ascmitc/mhl-specification) repository on github:

* [https://github.com/ascmitc/mhl-specification](https://github.com/ascmitc/mhl-specification). 

